==> corekeyboard-4.2.0.tar.gz: corekeyboard-v4.2.0/README.md <==
# CoreKeyboard
A virtual keyboard for X11 for C Suite.
This project uses X11 functions from from [kvkbd](https://github.com/KDE/kvkbd).

<img src="corekeyboard.png" width="500">

### Download
You can download latest release.
* [Source](https://gitlab.com/cubocore/coreapps/corekeyboard/tags)
* [ArchPackages](https://gitlab.com/cubocore/wiki/tree/master/ArchPackages)
* [DebPackages](https://gitlab.com/cubocore/wiki/-/tree/master/DebPackages)
* [Gentoo](https://gitweb.gentoo.org/repo/proj/guru.git/tree/gui-apps/corekeyboard)
* [AppImages](https://gitlab.com/cubocore/wiki/-/tree/master/AppImages)
* [Flatpak](https://flathub.org/apps/details/org.cubocore.CoreKeyboard)

### Dependencies
- qt5-base
- qt5-x11extras
- libxtst
- libx11
- [libcprime](https://gitlab.com/cubocore/libcprime)

### Known issues:
- The mod keys(ctrl, alt, alt gr, pg up, pg down, ...) may not work if you're
  not using Xserver >= 1.5 with evdev enabled due to changes in the keys mapping.
  This bug might have percolated from kvkbd project. No correction procedures were taken

### Information
Please see the [Wiki page](https://gitlab.com/cubocore/wiki) for this info.
* Changes in latest release ([ChangeLog](https://gitlab.com/cubocore/wiki/-/blob/master/ChangeLog))
* Build from the source ([BuildInfo](https://gitlab.com/cubocore/wiki/blob/master/BuildInfo.md))
* Tested In ([Test System](https://gitlab.com/cubocore/wiki/blob/master/TestSystem))
* Known Bugs ([Current list of issues](https://gitlab.com/groups/cubocore/coreapps/-/issues))
* Help Us

### Feedback
* We need your feedback to improve the C Suite. Send us your feedback through GitLab [issues](https://gitlab.com/groups/cubocore/coreapps/-/issues).
  
  Or feel free to join and chat with us in IRC/Matrix #cubocore:matrix.org or [Element.io](https://app.element.io/#/room/#cubocore:matrix.org)

==> corekeyboard-5.0.0.tar.gz: corekeyboard-v5.0.0/README.md <==
# CoreKeyboard
A virtual keyboard for X11 for C Suite.
This project uses X11 functions from from [kvkbd](https://github.com/KDE/kvkbd).

<img src="corekeyboard.png" width="500">

### Download
You can download latest release.
* [Source](https://gitlab.com/cubocore/coreapps/corekeyboard/tags)
* [ArchPackages](https://gitlab.com/cubocore/wiki/tree/master/ArchPackages)
* [DebPackages](https://gitlab.com/cubocore/wiki/-/tree/master/DebPackages)
* [Gentoo](https://gitweb.gentoo.org/repo/proj/guru.git/tree/gui-apps/corekeyboard)
* [AppImages](https://gitlab.com/cubocore/wiki/-/tree/master/AppImages)
* [Flatpak](https://flathub.org/apps/details/cc.cubocore.CoreKeyboard)

### Dependencies
- qt6-base
- libxtst
- libx11
- [libcprime](https://gitlab.com/cubocore/libcprime)

### Known issues:
- The mod keys(ctrl, alt, alt gr, pg up, pg down, ...) may not work if you're
  not using Xserver >= 1.5 with evdev enabled due to changes in the keys mapping.
  This bug might have percolated from kvkbd project. No correction procedures were taken

### Information
Please see the [Wiki page](https://gitlab.com/cubocore/wiki) for this info.
* Changes in latest release ([ChangeLog](https://gitlab.com/cubocore/wiki/-/blob/master/ChangeLog))
* Build from the source ([BuildInfo](https://gitlab.com/cubocore/wiki/blob/master/BuildInfo.md))
* Tested In ([Test System](https://gitlab.com/cubocore/wiki/blob/master/TestSystem))
* Known Bugs ([Current list of issues](https://gitlab.com/groups/cubocore/coreapps/-/issues))
* Help Us

### Feedback
* We need your feedback to improve the C Suite. Send us your feedback through GitLab [issues](https://gitlab.com/groups/cubocore/coreapps/-/issues).
  
  Or feel free to join and chat with us in IRC/Matrix #cubocore:matrix.org or [Element.io](https://app.element.io/#/room/#cubocore:matrix.org)
